# Luketils

Luke Wood's personal Python utility package.
I'm the original author of [KerasCV](https://github.com/keras-team/keras-cv).

Most of the time when I have a feature idea I add them in KerasCV - but sometimes I have utilities in mind that may not be suitable for Keras.
This package serves as a home for these utilities.

